import Link from "next/link";
import { useParams, usePathname } from "next/navigation";

import { cn } from "@/lib/utils";
import { Badge } from "@/components/ui/badge";
import { buttonVariants } from "@/components/ui/button";
import { Separator } from "@/components/ui/separator";
import {
  Tooltip,
  TooltipContent,
  TooltipTrigger,
} from "@/components/ui/tooltip";

// import { WorkspaceSwitcher } from "../../_components/workspace-switcher";
import { Fragment } from "react";
import { ScrollArea, ScrollBar } from "./ui/scroll-area";
import { NavItem, sideNavItems } from "@/config/nav";

const CollapsedItem = ({
  item,
  currentPath,
}: {
  item: NavItem;
  currentPath: string;
}) => {
  return (
    <Tooltip delayDuration={0}>
      <TooltipTrigger asChild>
        <Link
          href={item.href}
          className={cn(
            buttonVariants({ variant: "ghost", size: "icon" }),
            "h-9 w-9",
            currentPath === item.href
              ? "bg-primary text-primary-foreground hover:bg-primary/90 hover:text-primary-foreground"
              : "transparent",
            "soon" === item.badge && "cursor-not-allowed opacity-80"
          )}
        >
          {item.icon && <item.icon className="h-4 w-4" />}
          <span className="sr-only">{item.title}</span>
        </Link>
      </TooltipTrigger>
      <TooltipContent side="right" className="flex items-center gap-4">
        {item.title}
        {item?.badge ? <Badge>Coming soon</Badge> : null}
      </TooltipContent>
    </Tooltip>
  );
};

const ExpandedItem = ({
  item,
  currentPath,
  onLinkClick,
}: {
  item: NavItem;
  currentPath: string;
  onLinkClick?: Function;
}) => {
  return (
    <Link
      onClick={() => onLinkClick && onLinkClick()}
      href={item.href}
      className={cn(
        buttonVariants({ variant: "ghost" }),
        "justify-start text-muted-foreground",
        currentPath === item.href
          ? "bg-primary text-primary-foreground hover:bg-primary/90 hover:text-primary-foreground"
          : "transparent"
        // "soon" === item.badge && "cursor-not-allowed opacity-80"
      )}
    >
      {item.icon && <item.icon className="mr-2 h-4 w-4" />}
      {item.title}
      <span className={cn("ml-auto")}>
        {item?.badge && <Badge>{item.badge}</Badge>}
      </span>
    </Link>
  );
};

// TODO: idx not needed as key when all items have unique hrefs
// also, the active link should be filtered by href and not idx
export function SidebarNav({ isCollapsed }: { isCollapsed: boolean }) {
  console.log("collapsed ", isCollapsed);
  const params = useParams<{ workspaceId: string }>();
  const path = usePathname();

  // remove the workspaceId from the path when comparing active links in sidebar
  const pathname = path.replace(`/${params.workspaceId}`, "") || "/";
  const [_, currentPath] = pathname.split("/");

  return (
    <ScrollArea className="h-[calc(100vh-53px)] flex-1">
      <nav
        className={cn("flex flex-col", {
          "items-center justify-center": isCollapsed,
        })}
      >
        {/* <div className="p-2">
        workspace
        <WorkspaceSwitcher isCollapsed={isCollapsed} />
      </div> */}

        {sideNavItems.map((group, i) => {
          return (
            <Fragment key={i}>
              {/* <Separator /> */}
              <div
                className="flex flex-col gap-1 p-2"
                // key={group.group}
                // key={i}
              >
                {/* <div>{group.group}</div> */}
                {!isCollapsed ? (
                  <h4 className="rounded-md px-2 mt-2 text-sm font-semibold">
                    {group.group}
                  </h4>
                ) : (
                  i !== 0 && <Separator />
                )}

                {group.items.map((link, idx) => {
                  return isCollapsed ? (
                    <CollapsedItem
                      // key={link.href + idx}

                      item={link}
                      currentPath={path}
                    />
                  ) : (
                    <ExpandedItem
                      // key={link.href + idx}
                      key={idx}
                      item={link}
                      currentPath={path}
                    />
                  );
                })}
              </div>
            </Fragment>
          );
        })}
      </nav>

      <ScrollBar orientation="vertical" />
    </ScrollArea>
  );
}

export { ExpandedItem };
